# -*- coding: utf-8 -*-

import argparse

from json import loads
from mixpanel import Consumer

from gevent.monkey import patch_all
from gevent.server import DatagramServer

patch_all()


parser = argparse.ArgumentParser(
	description='''Mixpanel Gevent Proxy.
Send me JSON encoded [endpoint, json_message] UDP datagram and I will
forward it using default mixpanel consumer.''',
)

parser.add_argument(
	'-p', '--port',
	default=8051,
	type=int,
	help='UDP port listen to',
)


args = parser.parse_args()


class MixpanelProxy (DatagramServer):
	def handle (self, data, address):
		print('Got %r' % data)
		consumer = Consumer()
		consumer.send(*loads(data))


def main ():
	print('Runnig mixpanel gevent proxy on port %d.' % args.port)
	MixpanelProxy(':%d' % args.port).serve_forever()


if __name__ == '__main__':
	main()



#!/usr/bin/env python
# -*- coding: utf-8 -

from setuptools import setup, find_packages


PACKAGES = find_packages()


setup(
	name = 'mixpanel_gevent_proxy',
	version = '1.0',

	packages = [
		'mixpanel_gevent_proxy'
	],

	package_dir = {'': '.'},

	author = 'Vitaliy Khamin',
	author_email = 'vitaliykhamin@gmail.com',
	maintainer = 'Vitaliy Khamin',
	maintainer_email = 'vitaliykhamin@gmail.com',
	description = 'Mixpanel Gevent Proxy',
	url = 'https://github.com/khamin/mixpanel_gevent_proxy',
	zip_safe = True,

	classifiers = (
		'Operating System :: OS Independent',
		'Programming Language :: Python'
	),

	dependency_links = [
	],

	install_requires = [
		'gevent',
		'mixpanel-py'
	],

	entry_points = {
		'console_scripts': [
			'mixpanel_gevent_proxy = mixpanel_gevent_proxy:main'
		]
	}
)
